==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/typescript/ProjenrcOptions.java <==
package io.github.cdklabs.projen.typescript;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.931Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.typescript.ProjenrcOptions")
@software.amazon.jsii.Jsii.Proxy(ProjenrcOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface ProjenrcOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) The name of the projenrc file.
     * <p>
     * Default: ".projenrc.ts"
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getFilename() {
        return null;
    }

    /**
     * (experimental) A directory tree that may contain *.ts files that can be referenced from your projenrc typescript file.
     * <p>
     * Default: "projenrc"
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getProjenCodeDir() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ProjenrcOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ProjenrcOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<ProjenrcOptions> {
        java.lang.String filename;
        java.lang.String projenCodeDir;

        /**
         * Sets the value of {@link ProjenrcOptions#getFilename}
         * @param filename The name of the projenrc file.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder filename(java.lang.String filename) {
            this.filename = filename;
            return this;
        }

        /**
         * Sets the value of {@link ProjenrcOptions#getProjenCodeDir}
         * @param projenCodeDir A directory tree that may contain *.ts files that can be referenced from your projenrc typescript file.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder projenCodeDir(java.lang.String projenCodeDir) {
            this.projenCodeDir = projenCodeDir;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ProjenrcOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public ProjenrcOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ProjenrcOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ProjenrcOptions {
        private final java.lang.String filename;
        private final java.lang.String projenCodeDir;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.filename = software.amazon.jsii.Kernel.get(this, "filename", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.projenCodeDir = software.amazon.jsii.Kernel.get(this, "projenCodeDir", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.filename = builder.filename;
            this.projenCodeDir = builder.projenCodeDir;
        }

        @Override
        public final java.lang.String getFilename() {
            return this.filename;
        }

        @Override
        public final java.lang.String getProjenCodeDir() {
            return this.projenCodeDir;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getFilename() != null) {
                data.set("filename", om.valueToTree(this.getFilename()));
            }
            if (this.getProjenCodeDir() != null) {
                data.set("projenCodeDir", om.valueToTree(this.getProjenCodeDir()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.typescript.ProjenrcOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ProjenrcOptions.Jsii$Proxy that = (ProjenrcOptions.Jsii$Proxy) o;

            if (this.filename != null ? !this.filename.equals(that.filename) : that.filename != null) return false;
            return this.projenCodeDir != null ? this.projenCodeDir.equals(that.projenCodeDir) : that.projenCodeDir == null;
        }

        @Override
        public final int hashCode() {
            int result = this.filename != null ? this.filename.hashCode() : 0;
            result = 31 * result + (this.projenCodeDir != null ? this.projenCodeDir.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/typescript/ProjenrcOptions.java <==
package io.github.cdklabs.projen.typescript;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.601Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.typescript.ProjenrcOptions")
@software.amazon.jsii.Jsii.Proxy(ProjenrcOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface ProjenrcOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) The name of the projenrc file.
     * <p>
     * Default: ".projenrc.ts"
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getFilename() {
        return null;
    }

    /**
     * (experimental) A directory tree that may contain *.ts files that can be referenced from your projenrc typescript file.
     * <p>
     * Default: "projenrc"
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getProjenCodeDir() {
        return null;
    }

    /**
     * (experimental) Whether to use <code>SWC</code> for ts-node.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getSwc() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ProjenrcOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ProjenrcOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<ProjenrcOptions> {
        java.lang.String filename;
        java.lang.String projenCodeDir;
        java.lang.Boolean swc;

        /**
         * Sets the value of {@link ProjenrcOptions#getFilename}
         * @param filename The name of the projenrc file.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder filename(java.lang.String filename) {
            this.filename = filename;
            return this;
        }

        /**
         * Sets the value of {@link ProjenrcOptions#getProjenCodeDir}
         * @param projenCodeDir A directory tree that may contain *.ts files that can be referenced from your projenrc typescript file.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder projenCodeDir(java.lang.String projenCodeDir) {
            this.projenCodeDir = projenCodeDir;
            return this;
        }

        /**
         * Sets the value of {@link ProjenrcOptions#getSwc}
         * @param swc Whether to use <code>SWC</code> for ts-node.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder swc(java.lang.Boolean swc) {
            this.swc = swc;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ProjenrcOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public ProjenrcOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ProjenrcOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ProjenrcOptions {
        private final java.lang.String filename;
        private final java.lang.String projenCodeDir;
        private final java.lang.Boolean swc;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.filename = software.amazon.jsii.Kernel.get(this, "filename", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.projenCodeDir = software.amazon.jsii.Kernel.get(this, "projenCodeDir", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.swc = software.amazon.jsii.Kernel.get(this, "swc", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.filename = builder.filename;
            this.projenCodeDir = builder.projenCodeDir;
            this.swc = builder.swc;
        }

        @Override
        public final java.lang.String getFilename() {
            return this.filename;
        }

        @Override
        public final java.lang.String getProjenCodeDir() {
            return this.projenCodeDir;
        }

        @Override
        public final java.lang.Boolean getSwc() {
            return this.swc;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getFilename() != null) {
                data.set("filename", om.valueToTree(this.getFilename()));
            }
            if (this.getProjenCodeDir() != null) {
                data.set("projenCodeDir", om.valueToTree(this.getProjenCodeDir()));
            }
            if (this.getSwc() != null) {
                data.set("swc", om.valueToTree(this.getSwc()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.typescript.ProjenrcOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ProjenrcOptions.Jsii$Proxy that = (ProjenrcOptions.Jsii$Proxy) o;

            if (this.filename != null ? !this.filename.equals(that.filename) : that.filename != null) return false;
            if (this.projenCodeDir != null ? !this.projenCodeDir.equals(that.projenCodeDir) : that.projenCodeDir != null) return false;
            return this.swc != null ? this.swc.equals(that.swc) : that.swc == null;
        }

        @Override
        public final int hashCode() {
            int result = this.filename != null ? this.filename.hashCode() : 0;
            result = 31 * result + (this.projenCodeDir != null ? this.projenCodeDir.hashCode() : 0);
            result = 31 * result + (this.swc != null ? this.swc.hashCode() : 0);
            return result;
        }
    }
}
